<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="zh_TW">
<context>
    <name>osd::DisPlayModeApplet</name>
    <message>
        <source>Duplicate</source>
        <translation>複制</translation>
    </message>
    <message>
        <source>Extend</source>
        <translation>擴展</translation>
    </message>
    <message>
        <source>Only on %1</source>
        <translation>僅 %1</translation>
    </message>
</context>
</TS>